@@ -163,7 +163,6 @@ fr_command_arj_list (FRCommand *comm)
 				      list__process_line,
 				      comm);
 
-	fr_process_clear (comm->process);
 	fr_process_begin_command (comm->process, "arj");
 	fr_process_add_arg (comm->process, "v");
 	fr_process_add_arg (comm->process, "-y");
@@ -346,6 +345,7 @@ fr_command_arj_class_init (FRCommandArjClass *class)
 static void 
 fr_command_arj_init (FRCommand *comm)
 {
+	comm->propCanModify                = TRUE;
 	comm->propAddCanUpdate             = TRUE; 
 	comm->propAddCanReplace            = TRUE; 
 	comm->propExtractCanAvoidOverwrite = TRUE;
