@@ -37,17 +37,6 @@
 #include "menu-callbacks.h"
 
 
-void
-new_window_cb (GtkWidget *widget, 
-	       void      *data)
-{
-	FRWindow *window;
-
-	window = window_new ();
-	gtk_widget_show (window->app);
-}
-
-
 void
 close_window_cb (GtkWidget *widget, 
 		 void      *data)
@@ -71,7 +60,16 @@ new_archive (GtkWidget *file_sel,
 	     FRWindow  *window, 
 	     gchar     *path)
 {
-	window_archive_new (window, path);	
+	FRWindow *archive_window;
+
+	if (window->archive_present) {
+		archive_window = window_new ();
+		gtk_widget_show (archive_window->app);
+	} else
+		archive_window = window;
+
+	window_archive_new (archive_window, path);	
+
 	gtk_widget_destroy (file_sel);
 }
 
@@ -178,7 +176,7 @@ new_file_ok_cb (GtkWidget *w,
 						  GTK_STOCK_DIALOG_ERROR,
 						  _("Could not create the archive"),
 						  _("You have to specify an archive name."),
-						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 						  NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -197,7 +195,7 @@ new_file_ok_cb (GtkWidget *w,
 						  GTK_STOCK_DIALOG_ERROR,
 						  _("Could not create the archive"),
 						  _("You don't have permission to create an archive in this folder"),
-						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 						  NULL);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -246,7 +244,7 @@ new_file_ok_cb (GtkWidget *w,
 							  GTK_STOCK_DIALOG_ERROR,
 							  _("Could not delete the old archive."),
 							  NULL,
-							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -284,20 +282,27 @@ new_archive_cb (GtkWidget *widget,
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
 	GtkWidget *hbox;
+	GtkWidget *vbox, *vbox2;
 	GtkWidget *opt_menu;
 	GtkWidget *menu;
 	char      *dir;
 
-	file_sel = gtk_file_selection_new (_("New Archive"));
+	file_sel = gtk_file_selection_new (_("New"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
 
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), vbox, TRUE, TRUE, 0);
+
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 6);
+
 	/**/
 
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
 
 	gtk_box_pack_start (GTK_BOX (hbox), 
 			    gtk_label_new (_("Archive type:")),
@@ -313,6 +318,7 @@ new_archive_cb (GtkWidget *widget,
 
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
 	g_object_set_data (G_OBJECT (file_sel), "fr_opt_menu", opt_menu);
+	g_object_set_data (G_OBJECT (window->app), "fr_file_sel", file_sel);
 	
 	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
 			  "clicked", 
@@ -366,7 +372,7 @@ save_file_ok_cb (GtkWidget *w,
 						  GTK_STOCK_DIALOG_ERROR,
 						  _("Could not save the archive"),
 						  _("You have to specify an archive name."),
-						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 						  NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -385,7 +391,7 @@ save_file_ok_cb (GtkWidget *w,
 						  GTK_STOCK_DIALOG_ERROR,
 						  _("Could not save the archive"),
 						  _("You don't have permission to create an archive in this folder"),
-						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 						  NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -425,7 +431,7 @@ save_file_ok_cb (GtkWidget *w,
 							  GTK_STOCK_DIALOG_ERROR,
 							  _("Could not delete the old archive."),
 							  NULL,
-							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -450,7 +456,7 @@ save_as_archive_cb (GtkWidget *widget,
 	GtkWidget *menu;
 	char      *dir;
 
-	file_sel = gtk_file_selection_new (_("Save Archive"));
+	file_sel = gtk_file_selection_new (_("Save"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
@@ -510,7 +516,7 @@ static void
 open_file_ok_cb (GtkWidget *w,
                  GtkWidget *file_sel)
 {
-	FRWindow   *window;
+	FRWindow   *window = NULL;
 	const char *path;
 
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
@@ -519,6 +525,8 @@ open_file_ok_cb (GtkWidget *w,
         if (path == NULL)
                 return;
 
+	g_print ("[-1]\n");
+
 	if (window_archive_open (window, path, GTK_WINDOW (file_sel)))
 		gtk_widget_destroy (file_sel);
 }
@@ -529,15 +537,19 @@ open_archive_cb (GtkWidget *widget,
 		 void      *data)
 {
 	GtkWidget *file_sel;
-	FRWindow *window = data;
-	gchar *dir;
+	FRWindow  *window = data;
+	char      *dir;
 
-        file_sel = gtk_file_selection_new (_("Open Archive"));
+	g_print ("[-2]\n");
+
+        file_sel = gtk_file_selection_new (_("Open"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
 
+	/**/
+
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
 	
 	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
@@ -555,7 +567,7 @@ open_archive_cb (GtkWidget *widget,
 			  G_CALLBACK (open_file_destroy_cb),
 			  file_sel);
 
-	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	gtk_widget_show (file_sel);
 }
 
@@ -648,7 +660,7 @@ copy_or_move_archive_ok_cb (GtkWidget    *w,
 							  GTK_STOCK_DIALOG_ERROR,
 							  _("Could not copy the archive"),
 							  NULL,
-							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -666,7 +678,7 @@ copy_or_move_archive_ok_cb (GtkWidget    *w,
 							  GTK_STOCK_DIALOG_ERROR,
 							  _("Could not move the archive"),
 							  NULL,
-							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -691,7 +703,7 @@ copy_or_move_archive (FRWindow *window,
 	data->window = window;
 	data->copy = copy;
 	data->overwrite = overwrite;
-	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy Archive") : _("Move Archive"));
+	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy") : _("Move"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
@@ -764,12 +776,12 @@ rename_archive_cb (GtkWidget *widget,
 	char       *dir, *filename, *new_filename;
 
 	name = remove_extension (file_name_from_path (window->archive_filename));
-	utf8_old_string = g_locale_to_utf8 (name, -1, NULL, NULL, NULL);
+	utf8_old_string = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
 	g_free (name);
 	utf8_string = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 					       (GTK_DIALOG_DESTROY_WITH_PARENT 
 						| GTK_DIALOG_MODAL),
-					       _("Rename Archive"),
+					       _("Rename"),
 					       _("New archive name (without extension)"),
 					       utf8_old_string,
 					       1024,
@@ -779,7 +791,7 @@ rename_archive_cb (GtkWidget *widget,
 	if (utf8_string == NULL)
 		return;
 
-	string = g_locale_from_utf8 (utf8_string, -1, NULL, NULL, NULL);
+	string = g_filename_from_utf8 (utf8_string, -1, NULL, NULL, NULL);
 	g_free (utf8_string);
 
 	filename = window->archive->filename;
@@ -922,8 +934,7 @@ void
 quit_cb (GtkWidget *widget, 
 	 void      *data)
 {
-	while (window_list)
-                window_close ((FRWindow*) window_list->data);
+	window_close ((FRWindow*) data);
 }
 
 
@@ -967,6 +978,30 @@ go_up_one_level_cb (GtkWidget *widget,
 }
 
 
+void
+go_home_cb (GtkWidget *widget, 
+	    void *data)
+{
+	window_go_to_location ((FRWindow*) data, "/");
+}
+
+
+void
+go_back_cb (GtkWidget *widget, 
+	    void *data)
+{
+	window_go_back ((FRWindow*) data);
+}
+
+
+void
+go_forward_cb (GtkWidget *widget, 
+	       void *data)
+{
+	window_go_forward ((FRWindow*) data);
+}
+
+
 void
 set_list_mode_flat_cb (GtkWidget *widget, 
 		       void *data)
@@ -1176,17 +1211,7 @@ sort_list_reversed (GtkWidget *widget,
 }
 
 
-/* -- stop_cb -- */
-
-
-void
-stop__step2 (gpointer data)
-{
-	FRWindow *window = data;
-
-	if (window->activity_ref > 0)
-		fr_process_stop (window->archive->process);
-}
+/**/
 
 
 void
@@ -1194,26 +1219,11 @@ stop_cb (GtkWidget *widget,
 	 void      *data)
 {
 	FRWindow *window = data;
-
-	if (! window->stoppable)
-		return;
-
-	if (window->vd_handle != NULL) {
-		visit_dir_async_interrupt (window->vd_handle, 
-					   stop__step2, 
-					   window);
-		window->vd_handle = NULL;
-		window_pop_message (window);
-		window_stop_activity_mode (window);
-
-		if (window->convert_data.converting) 
-			window_convert_data_free (window);
-
-	} else
-		stop__step2 (window);
+	window_stop (window);
 }
 
 
+
 /**/
 
 
@@ -1259,3 +1269,34 @@ view_statusbar_cb (GtkWidget *widget,
 {
 	eel_gconf_set_boolean (PREF_UI_STATUSBAR, GTK_CHECK_MENU_ITEM (widget)->active);
 }
+
+
+void
+rename_cb (GtkWidget *widget, 
+	   void *data)
+{
+	window_rename_selection ((FRWindow*) data);
+}
+
+
+void
+cut_cb (GtkWidget *widget, 
+	void *data)
+{
+	window_cut_selection ((FRWindow*) data);
+}
+
+
+void
+copy_cb (GtkWidget *widget, 
+	 void *data)
+{
+	window_copy_selection ((FRWindow*) data);
+}
+
+void
+paste_cb (GtkWidget *widget, 
+	  void *data)
+{
+	window_paste_selection ((FRWindow*) data);
+}
