@@ -72,7 +72,8 @@ typedef enum {
 	FR_PROC_ERROR_COMMAND_NOT_FOUND,
 	FR_PROC_ERROR_EXITED_ABNORMALLY,
 	FR_PROC_ERROR_SPAWN,
-	FR_PROC_ERROR_STOPPED
+	FR_PROC_ERROR_STOPPED,
+	FR_PROC_ERROR_ASK_PASSWORD
 } FRProcErrorType;
 
 
